/**
 * @function
 * @param {Object<selected: Array<Object>, items: Array<Object>>} state - reducer`s state
 * @param {Array<Object>} params - update parameters list
 * @return {Object<selected: Array<Object>, items: Array<Object>>} - new state
* */
export function updatedReducerFunc(state, params) {
    const itemsMap = state.items.reduce((memo, item) => {
        memo[item.obj_uid] = item;
        return memo;
    }, {});

    for (const item of params) {
        itemsMap[item.obj_uid] = item;
    }

    return {...state, items: Object.values(itemsMap)};
}

export function singleSelectReducerFunc(state, params, identifier) {
    const isSelected = state.selected.find(item => item[identifier] === params[identifier]);
    if (isSelected) {
        return { ...state, selected: state.selected.filter(item => item[identifier] !== params[identifier]) };
    }
    return { ...state, selected: [...state.selected, params] };
}

export function bulkSelectReducerFunc(state, params, identifier) {
    const selected = params.reduce((memo, item) => memo.filter(selectedItem => item[identifier] !== selectedItem[identifier]), state.selected);
    
    selected.push(...params);
    
    return { ...state, selected };
}

export function unselectReducerFunc(state, params, identifier) {
    const selected = [];
    state.selected.forEach((item) => {
        const isSelected = params.find(unselectItem => unselectItem[identifier] === item[identifier]);
        if (!isSelected) {
            selected.push(item);
        }
    });
    return { ...state, selected };
}
