import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION, COMPONENTS } from 'common/ui-labels';
import { selectDeleteVehicleStatus, selectCheckedVehicles } from '../store/selectors';
import { closeDeleteVehicleCertModal, deleteVehicleCertification, unselectTableVehicle } from '../store/actions';


function DeleteVehicleCertificationForm(props) {
    const { close, submit, className } = props;
    return (
        <form className={className}>
            <div
                className="col-md-12"
                style={{ overflowY: 'auto', overflowX: 'hidden' }}
            >
                <div className="Form-Buttons">
                    <button type="button" onClick={submit} data-id="vehicle-cert-delete-ok">{COMPONENTS.BUTTONS.OK}</button>
                    <button type="button" data-id="vehicle-cert-delete-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
                </div>
            </div>
        </form>
    );
}

DeleteVehicleCertificationForm.defaultProps = {
    close: () => {},
    submit: () => {},
    className: '',
};

DeleteVehicleCertificationForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
};

export default function DeleteVehicleCertification(props) {
    const dispatch = useDispatch();
    const open = useSelector(selectDeleteVehicleStatus);
    const vehicles = useSelector(selectCheckedVehicles);
    const { style } = props;
    
    function submit() {
        dispatch(deleteVehicleCertification(vehicles));
        dispatch(unselectTableVehicle(vehicles));
        dispatch(closeDeleteVehicleCertModal());
    }
    function close() {
        dispatch(closeDeleteVehicleCertModal());
    }
    
    return (
        <Modal
            contentLabel="deleteVehicleCertification"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header">
                    {VEHICLE_CERTIFICATION.DELETE_VEHICLE_MODAL_TITLE}
                </span>
                <DeleteVehicleCertificationForm
                    className="Modal-Form"
                    close={close}
                    submit={submit}
                />
            </div>
        </Modal>
    );
}

DeleteVehicleCertification.propTypes = {
    style: PropTypes.shape({}),
};

DeleteVehicleCertification.defaultProps = {
    style: {},
};
