import * as api from '../../api';
import { ACTIONS } from '../../common/constants';
import { errorHandlerGetRequest } from '../../../../src/js/stores/actions/errorHandlerActions';


export const loadDriversCertifications = () => async (dispatch) => {
    try {
        const driversCertifications = await api.loadDriversCertifications();
        dispatch({
            type: ACTIONS.DRIVER_LICENSES_SET,
            params: driversCertifications,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

export const deleteDriverCertification = (drivers, uncertified) => async (dispatch) => {
    const promises = [];
    
    for (let i = 0; i < drivers.length; i += 1) {
        const driver = drivers[i];
        const certification = driver.certification.reduce((result, cert) => {
            if (cert.id !== uncertified.id) {
                result.push(cert);
            }
            return result;
        }, []);
        
        const driverCertification = { obj_uid: driver.obj_uid, certification };
        promises.push(api.editDriverCertification(driverCertification)
            .then((result) => {
                dispatch({
                    type: ACTIONS.DRIVER_LICENSES_UPDATED,
                    params: result,
                });
            })
            .catch((err) => {
                errorHandlerGetRequest(err, dispatch);
            }));
    }
    return Promise.all(promises);
};

export const updateDriverCertification = params => async (dispatch) => {
    const promises = [];
    
    for (let i = 0; i < params.length; i += 1) {
        const driverCertification = { obj_uid: params[i].obj_uid, certification: params[i].certification };
        promises.push(api.editDriverCertification(driverCertification)
            .then((result) => {
                dispatch({
                    type: ACTIONS.DRIVER_LICENSES_UPDATED,
                    params: result,
                });
            })
            .catch((err) => {
                errorHandlerGetRequest(err, dispatch);
            }));
    }
    return Promise.all(promises);
};

export const selectTableDriver = params => ({
    type: ACTIONS.DRIVER_LICENSES_SINGLE_SELECT,
    params,
});

export const selectTableDrivers = params => ({
    type: ACTIONS.DRIVER_LICENSES_SELECT,
    params,
});

export const unselectTableDrivers = params => ({
    type: ACTIONS.DRIVER_LICENSES_UNSELECT,
    params,
});
