import { getNotifyParams } from 'utils/storeUtils';
import { ACTIONS, NOTIFY_ACTIONS } from '../../common/constants';
import { bulkSelectReducerFunc, singleSelectReducerFunc, unselectReducerFunc, updatedReducerFunc } from '../../common/utils';


const initialState = { items: [], selected: [] };

// driverCertification
// { obj_uid: 'Rbq7iaEBSLChBU8YXzIMfw', certification: [{ id: 3, name: 'Model C' }] }
function updatedParams(params) {
    if (params.driver_lic) {
        return {
            obj_uid: params.obj_uid,
            certification: params.driver_lic.map(cert => ({
                id: cert.id,
                certification_required: cert.certification_required,
            })),
        };
    }
    return params;
}

const driverCertifications = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.DRIVER_LICENSES_SET: {
            return { ...initialState, items: [...action.params] };
        }
        case ACTIONS.VEHICLE_MODELS_UPDATED: {
            const vehicleModel = action.params;
            const newState = { ...state, items: [] };
            state.items.forEach((item) => {
                const certification = item.certification.map(cert => ({
                    id: cert.id,
                    name: cert.id === vehicleModel.id ? vehicleModel.name : cert.name,
                    certification_required: cert.id === vehicleModel.id ? vehicleModel.certification_required : cert.certification_required,
                }));
                newState.items.push({ ...item, certification });
            });
            return newState;
        }
        case NOTIFY_ACTIONS.DRIVER_LICENSES_UPDATED:
        case ACTIONS.DRIVER_LICENSES_UPDATED: {
            const rowParams = getNotifyParams(action);
            const params = rowParams.map(param => updatedParams(param));
            return updatedReducerFunc(state, params);
        }
        case ACTIONS.DRIVER_LICENSES_SINGLE_SELECT: {
            return singleSelectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.DRIVER_LICENSES_SELECT: {
            return bulkSelectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.DRIVER_LICENSES_UNSELECT: {
            return unselectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.CLEAR_SELECTED_DRIVERS_VEHICLES: {
            return { ...state, selected: [] };
        }
        default:
            return state;
    }
};

export default driverCertifications;
