DELIMITER /

DROP TABLE IF EXISTS `vehicle_models`;

CREATE TABLE `vehicle_models` (

                                  `model` VARCHAR(255) NOT NULL DEFAULT '',
                                  `id` INT NULL DEFAULT NULL,
                                  `company_uid` CHAR(22) NOT NULL,
                                  UNIQUE INDEX `model_company_uid` (`model`, `company_uid`)
)
    COLLATE='utf8mb4_unicode_ci'
    ENGINE=InnoDB
/

DROP TABLE IF EXISTS `driver_certifications`;

CREATE TABLE `driver_certifications` (
                                         `obj_uid` CHAR(22) NOT NULL,
                                         `id` INT NOT NULL DEFAULT 0,
                                         `company_uid` CHAR(22) NOT NULL
)
    COLLATE='utf8mb4_unicode_ci'
    ENGINE=InnoDB
/

DROP TABLE IF EXISTS `vehicles_model_associations`;

CREATE TABLE `vehicles_model_associations` (
                                               `obj_uid` CHAR(22) NOT NULL,
                                               `id` VARCHAR(255) NOT NULL DEFAULT '',
                                               `company_uid` CHAR(22) NOT NULL
)
    COLLATE='utf8mb4_unicode_ci'
    ENGINE=InnoDB
/

INSERT INTO sequence_data
(sequence_name, sequence_increment, sequence_max_value)
SELECT CONCAT_WS('-', 'vehicle_models', uid) , 1 , 255 from view_companies
ON DUPLICATE KEY UPDATE
    sequence_max_value = 255;
/

DROP TRIGGER IF EXISTS `t_models_insert`/

CREATE TRIGGER `t_models_insert` BEFORE INSERT ON `vehicle_models` FOR EACH ROW BEGIN
    IF NEW.id <> 0  OR NEW.id IS NULL THEN
        SET @new_id = nextval_seq(CONCAT_WS('-', 'vehicle_models', NEW.company_uid));
        SET NEW.id = @new_id;
    END IF;
END/

DROP TRIGGER IF EXISTS `t_models_before_delete`/
DROP TRIGGER IF EXISTS `t_models_after_delete`/

CREATE TRIGGER `t_models_after_delete` AFTER DELETE ON `vehicle_models` FOR EACH ROW BEGIN
    DECLARE val BIGINT(20) UNSIGNED;
    IF (OLD.id <> 0 AND OLD.company_uid IS NOT NULL) THEN
        set val := dropval(CONCAT_WS('-', 'vehicle_models', OLD.company_uid), OLD.id);
    END IF;
END/
