DELIMITER /

DROP TABLE IF EXISTS `vehicle_models` /

DROP TABLE IF EXISTS `driver_certifications` /

DROP TABLE IF EXISTS `vehicles_model_associations` /


CREATE TABLE `vehicle_models` (
                                  `model`                   varchar(255)  COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
                                  `id`                      int(11)       DEFAULT NULL,
                                  `certification_required`  int(11)       DEFAULT NULL,
                                  `company_uid`             char(22)      COLLATE utf8mb4_unicode_ci NOT NULL,
                                  `project_uid`             char(22)      COLLATE utf8mb4_unicode_ci NOT NULL,
                                  UNIQUE KEY `model_id_company_project_uid` (`model`,`id`,`company_uid`,`project_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci /

CREATE TABLE `driver_certifications` (
                                         `obj_uid`       char(22)    COLLATE utf8mb4_unicode_ci NOT NULL,
                                         `id`            int(11)     NOT NULL DEFAULT 0,
                                         `company_uid`   char(22)    COLLATE utf8mb4_unicode_ci NOT NULL,
                                         `project_uid`   char(22)    COLLATE utf8mb4_unicode_ci NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci /

CREATE TABLE `vehicles_model_associations` (
                                               `obj_uid`       char(22)    COLLATE utf8mb4_unicode_ci NOT NULL,
                                               `id`            int(11)     NOT NULL DEFAULT 0,
                                               `company_uid`   char(22)    COLLATE utf8mb4_unicode_ci NOT NULL,
                                               `project_uid`   char(22)    COLLATE utf8mb4_unicode_ci NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci /


INSERT INTO sequence_data
(sequence_name, sequence_increment, sequence_max_value)
SELECT CONCAT_WS('-', 'vehicle_models', uid) , 1 , 32 from view_projects
ON DUPLICATE KEY UPDATE
    sequence_max_value = 32;
/





DROP TRIGGER IF EXISTS `t_models_insert`/

CREATE TRIGGER `t_models_insert` BEFORE INSERT ON `vehicle_models` FOR EACH ROW BEGIN
    IF NEW.id <> 0  OR NEW.id IS NULL THEN
        SET @new_id = nextval_seq(CONCAT_WS('-', 'vehicle_models', NEW.project_uid));
        SET NEW.id = @new_id;
    END IF;
END/

DROP TRIGGER IF EXISTS `t_models_before_delete`/
DROP TRIGGER IF EXISTS `t_models_after_delete`/

CREATE TRIGGER `t_models_after_delete` AFTER DELETE ON `vehicle_models` FOR EACH ROW BEGIN
    DECLARE val BIGINT(20) UNSIGNED;
    IF (OLD.id <> 0 AND OLD.project_uid IS NOT NULL) THEN
        set val := dropval(CONCAT_WS('-', 'vehicle_models', OLD.project_uid), OLD.id);
    END IF;
END/



DROP TRIGGER IF EXISTS  `t_tags_after_insert` /

CREATE TRIGGER `t_tags_after_insert` AFTER INSERT ON `tags` FOR EACH ROW BEGIN
    IF NEW.role_uid = 'DhE-KsKqEeagPwhgboMCKw' THEN
        INSERT INTO sequence_data
        (sequence_name, sequence_increment, sequence_max_value, drop_value)
            (SELECT CONCAT_WS('-', 'vehicle_models', NEW.uid) , 1 , 32, 0);
    END IF;
END /

UPDATE sequence_data
SET sequence_max_value = 32
WHERE  sequence_name LIKE  'vehicle_models%' AND drop_value = 0/


