const express = require('express');
const middlewares = require('middlewares');
const Handlers = require('./handlers');
const Scheme = require('./validation_scheme');
const { DISPATCHER: { SUBSCRIPTIONS } } = require('enums').OBJECT_TYPE;
const { VehiclesEventHandler } = require('./VehiclesEventHandler');
const { EventSubscription } = require('../../../models/EventSubscription');
const { eventsConsumer } = require('../../../providers/eventsConsumer');

const { validate } = middlewares;
const router = express.Router();

eventsConsumer.subscribe(new EventSubscription(SUBSCRIPTIONS.UNCERTIFIED_OPERATIONS_START, VehiclesEventHandler.nodeEventHandler));
eventsConsumer.subscribe(new EventSubscription(SUBSCRIPTIONS.UNCERTIFIED_OPERATIONS_STOP, VehiclesEventHandler.nodeEventHandler));
eventsConsumer.subscribe(new EventSubscription(SUBSCRIPTIONS.NODE_ANNOUNCE, VehiclesEventHandler.nodeNAHandler));
eventsConsumer.subscribe(new EventSubscription(SUBSCRIPTIONS.TRACKABLE_DELETED, VehiclesEventHandler.trackableDeleteHandler));
eventsConsumer.subscribe(new EventSubscription(SUBSCRIPTIONS.TRACKABLE_UPDATED, VehiclesEventHandler.trackableUpdateHandler));

router.use(middlewares.token());
router.use(middlewares.scope());
router.use(middlewares.projectTag());

router.get('/driver_licenses', Handlers.getDriverLicenses);
router.put('/driver_licenses', validate(Scheme.driver_licenses_update), Handlers.editDriverLicenses);
router.get('/vehicle_certifications', Handlers.getVehiclesCertifications);
router.put('/vehicle_certifications', validate(Scheme.vehicle_certifications_update), Handlers.editVehicleCertificationClass);
router.get('/vehicle_models', Handlers.getVehicleModels);
router.post('/vehicle_models', validate(Scheme.vehicle_model_create), Handlers.createVehicleModel);
router.put('/vehicle_models/:id', validate(Scheme.vehicle_model_update), Handlers.updateVehicleModel);
router.delete('/vehicle_models/:id', Handlers.deleteVehicleModel);


module.exports = {
    router,
    path: 'wsc',
};
